==> libgwenhywfar_3.2.0.orig.tar.gz: gwenhywfar-3.2.0/plugins/dbio/olddb/olddb_p.h <==
/***************************************************************************
 $RCSfile$
 -------------------
 cvs         : $Id: olddb_p.h 1393 2007-11-22 18:26:05Z martin $
 begin       : Thu Oct 30 2003
 copyright   : (C) 2003 by Martin Preuss
 email       : martin@libchipcard.de

 ***************************************************************************
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Lesser General Public            *
 *   License as published by the Free Software Foundation; either          *
 *   version 2.1 of the License, or (at your option) any later version.    *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,                 *
 *   MA  02111-1307  USA                                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef GWENHYWFAR_PLUGIN_OLDDB_H
#define GWENHYWFAR_PLUGIN_OLDDB_H


#include <gwenhywfar/bufferedio.h>
#include <gwenhywfar/db.h>
#include <gwenhywfar/dbio.h>
#include <gwenhywfar/stringlist.h>

#define GWEN_DBIO_OLDDB_MAXVALUE_LEN (16*1024)


GWEN_DBIO *olddb_factory();


static int GWEN_DBIO_OldDb_Export(GWEN_DBIO *dbio,
				  GWEN_IO_LAYER *io,
				  GWEN_DB_NODE *data,
				  GWEN_DB_NODE *cfg,
				  uint32_t flags,
				  uint32_t guiid,
				  int msecs);

static int GWEN_DBIO_OldDb_Import(GWEN_DBIO *dbio,
				  GWEN_IO_LAYER *io,
				  GWEN_DB_NODE *data,
				  GWEN_DB_NODE *cfg,
				  uint32_t flags,
				  uint32_t guiid,
				  int msecs);

static GWEN_DBIO_CHECKFILE_RESULT GWEN_DBIO_OldDb_CheckFile(GWEN_DBIO *dbio,
							    const char *fname,
							    uint32_t guiid,
							    int msecs);




#endif

==> libgwenhywfar_3.11.3.orig.tar.gz: gwenhywfar-3.11.3/plugins/dbio/olddb/olddb_p.h <==
/***************************************************************************
 $RCSfile$
 -------------------
 cvs         : $Id$
 begin       : Thu Oct 30 2003
 copyright   : (C) 2003 by Martin Preuss
 email       : martin@libchipcard.de

 ***************************************************************************
 *                                                                         *
 *   This library is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU Lesser General Public            *
 *   License as published by the Free Software Foundation; either          *
 *   version 2.1 of the License, or (at your option) any later version.    *
 *                                                                         *
 *   This library is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU     *
 *   Lesser General Public License for more details.                       *
 *                                                                         *
 *   You should have received a copy of the GNU Lesser General Public      *
 *   License along with this library; if not, write to the Free Software   *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston,                 *
 *   MA  02111-1307  USA                                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef GWENHYWFAR_PLUGIN_OLDDB_H
#define GWENHYWFAR_PLUGIN_OLDDB_H


#include <gwenhywfar/bufferedio.h>
#include <gwenhywfar/db.h>
#include <gwenhywfar/dbio.h>
#include <gwenhywfar/stringlist.h>

#define GWEN_DBIO_OLDDB_MAXVALUE_LEN (16*1024)


GWENHYWFAR_EXPORT
GWEN_PLUGIN *dbio_olddb_factory(GWEN_PLUGIN_MANAGER *pm,
				const char *modName,
				const char *fileName);


static int GWEN_DBIO_OldDb_Export(GWEN_DBIO *dbio,
				  GWEN_IO_LAYER *io,
				  GWEN_DB_NODE *data,
				  GWEN_DB_NODE *cfg,
				  uint32_t flags,
				  uint32_t guiid,
				  int msecs);

static int GWEN_DBIO_OldDb_Import(GWEN_DBIO *dbio,
				  GWEN_IO_LAYER *io,
				  GWEN_DB_NODE *data,
				  GWEN_DB_NODE *cfg,
				  uint32_t flags,
				  uint32_t guiid,
				  int msecs);

static GWEN_DBIO_CHECKFILE_RESULT GWEN_DBIO_OldDb_CheckFile(GWEN_DBIO *dbio,
							    const char *fname,
							    uint32_t guiid,
							    int msecs);




#endif
